@@ -4,6 +4,7 @@ except ImportError:
     import unittest
 
 import rope.base.evaluate
+from rope.base import libutils
 from rope.base import exceptions, worder, codeanalyze
 from rope.base.codeanalyze import (SourceLinesAdapter,
                                    LogicalLineFinder, get_block_start)
@@ -347,7 +348,6 @@ class ScopeNameFinderTest(unittest.TestCase):
     def setUp(self):
         super(ScopeNameFinderTest, self).setUp()
         self.project = testutils.sample_project()
-        self.pycore = self.project.pycore
 
     def tearDown(self):
         testutils.remove_project(self.project)
@@ -357,14 +357,14 @@ class ScopeNameFinderTest(unittest.TestCase):
     # exception, but not in class bodies
     def xxx_test_global_name_in_class_body(self):
         code = 'a_var = 10\nclass C(object):\n    a_var = a_var\n'
-        scope = self.pycore.get_string_scope(code)
+        scope = libutils.get_string_scope(self.project, code)
         name_finder = rope.base.evaluate.ScopeNameFinder(scope.pyobject)
         result = name_finder.get_pyname_at(len(code) - 3)
         self.assertEquals(scope['a_var'], result)
 
     def test_class_variable_attribute_in_class_body(self):
         code = 'a_var = 10\nclass C(object):\n    a_var = a_var\n'
-        scope = self.pycore.get_string_scope(code)
+        scope = libutils.get_string_scope(self.project, code)
         name_finder = rope.base.evaluate.ScopeNameFinder(scope.pyobject)
         a_var_pyname = scope['C'].get_object()['a_var']
         result = name_finder.get_pyname_at(len(code) - 12)
@@ -372,7 +372,7 @@ class ScopeNameFinderTest(unittest.TestCase):
 
     def test_class_variable_attribute_in_class_body2(self):
         code = 'a_var = 10\nclass C(object):\n    a_var \\\n= a_var\n'
-        scope = self.pycore.get_string_scope(code)
+        scope = libutils.get_string_scope(self.project, code)
         name_finder = rope.base.evaluate.ScopeNameFinder(scope.pyobject)
         a_var_pyname = scope['C'].get_object()['a_var']
         result = name_finder.get_pyname_at(len(code) - 12)
@@ -380,7 +380,7 @@ class ScopeNameFinderTest(unittest.TestCase):
 
     def test_class_method_attribute_in_class_body(self):
         code = 'class C(object):\n    def a_method(self):\n        pass\n'
-        scope = self.pycore.get_string_scope(code)
+        scope = libutils.get_string_scope(self.project, code)
         name_finder = rope.base.evaluate.ScopeNameFinder(scope.pyobject)
         a_method_pyname = scope['C'].get_object()['a_method']
         result = name_finder.get_pyname_at(code.index('a_method') + 2)
@@ -388,7 +388,7 @@ class ScopeNameFinderTest(unittest.TestCase):
 
     def test_inner_class_attribute_in_class_body(self):
         code = 'class C(object):\n    class CC(object):\n        pass\n'
-        scope = self.pycore.get_string_scope(code)
+        scope = libutils.get_string_scope(self.project, code)
         name_finder = rope.base.evaluate.ScopeNameFinder(scope.pyobject)
         a_class_pyname = scope['C'].get_object()['CC']
         result = name_finder.get_pyname_at(code.index('CC') + 2)
@@ -396,7 +396,7 @@ class ScopeNameFinderTest(unittest.TestCase):
 
     def test_class_method_in_class_body_but_not_indexed(self):
         code = 'class C(object):\n    def func(self, func):\n        pass\n'
-        scope = self.pycore.get_string_scope(code)
+        scope = libutils.get_string_scope(self.project, code)
         a_func_pyname = scope.get_scopes()[0].get_scopes()[0]['func']
         name_finder = rope.base.evaluate.ScopeNameFinder(scope.pyobject)
         result = name_finder.get_pyname_at(code.index(', func') + 3)
@@ -404,7 +404,7 @@ class ScopeNameFinderTest(unittest.TestCase):
 
     def test_function_but_not_indexed(self):
         code = 'def a_func(a_func):\n    pass\n'
-        scope = self.pycore.get_string_scope(code)
+        scope = libutils.get_string_scope(self.project, code)
         a_func_pyname = scope['a_func']
         name_finder = rope.base.evaluate.ScopeNameFinder(scope.pyobject)
         result = name_finder.get_pyname_at(code.index('a_func') + 3)
@@ -415,9 +415,9 @@ class ScopeNameFinderTest(unittest.TestCase):
         mod = testutils.create_module(self.project, 'mod', root_folder)
         mod.write('def a_func():\n    pass\n')
         code = 'from mod import a_func\n'
-        scope = self.pycore.get_string_scope(code)
+        scope = libutils.get_string_scope(self.project, code)
         name_finder = rope.base.evaluate.ScopeNameFinder(scope.pyobject)
-        mod_pyobject = self.pycore.resource_to_pyobject(mod)
+        mod_pyobject = self.project.get_pymodule(mod)
         found_pyname = name_finder.get_pyname_at(code.index('mod') + 1)
         self.assertEquals(mod_pyobject, found_pyname.get_object())
 
@@ -425,14 +425,14 @@ class ScopeNameFinderTest(unittest.TestCase):
         mod1 = testutils.create_module(self.project, 'mod1')
         mod1.write('def afunc():\n    pass\n')
         code = 'from mod1 import (\n    afunc as func)\n'
-        scope = self.pycore.get_string_scope(code)
+        scope = libutils.get_string_scope(self.project, code)
         name_finder = rope.base.evaluate.ScopeNameFinder(scope.pyobject)
-        mod_pyobject = self.pycore.resource_to_pyobject(mod1)
+        mod_pyobject = self.project.get_pymodule(mod1)
         afunc = mod_pyobject['afunc']
         found_pyname = name_finder.get_pyname_at(code.index('afunc') + 1)
         self.assertEquals(afunc.get_object(), found_pyname.get_object())
 
-    @testutils.run_only_for_25
+    @testutils.only_for('2.5')
     def test_relative_modules_after_from_statements(self):
         pkg1 = testutils.create_package(self.project, 'pkg1')
         pkg2 = testutils.create_package(self.project, 'pkg2', pkg1)
@@ -441,9 +441,9 @@ class ScopeNameFinderTest(unittest.TestCase):
         mod1.write('def a_func():\n    pass\n')
         code = 'from ..mod1 import a_func\n'
         mod2.write(code)
-        mod2_scope = self.pycore.resource_to_pyobject(mod2).get_scope()
+        mod2_scope = self.project.get_pymodule(mod2).get_scope()
         name_finder = rope.base.evaluate.ScopeNameFinder(mod2_scope.pyobject)
-        mod1_pyobject = self.pycore.resource_to_pyobject(mod1)
+        mod1_pyobject = self.project.get_pymodule(mod1)
         found_pyname = name_finder.get_pyname_at(code.index('mod1') + 1)
         self.assertEquals(mod1_pyobject, found_pyname.get_object())
 
@@ -454,36 +454,36 @@ class ScopeNameFinderTest(unittest.TestCase):
         mod2 = testutils.create_module(self.project, 'mod2', pkg2)  # noqa
         mod1.write('import pkg1.pkg2.mod2')
 
-        mod1_scope = self.pycore.resource_to_pyobject(mod1).get_scope()
+        mod1_scope = self.project.get_pymodule(mod1).get_scope()
         name_finder = rope.base.evaluate.ScopeNameFinder(mod1_scope.pyobject)
-        pkg2_pyobject = self.pycore.resource_to_pyobject(pkg2)
+        pkg2_pyobject = self.project.get_pymodule(pkg2)
         found_pyname = name_finder.get_pyname_at(mod1.read().index('pkg2') + 1)
         self.assertEquals(pkg2_pyobject, found_pyname.get_object())
 
     def test_get_pyname_at_on_language_keywords(self):
         code = 'def a_func(a_func):\n    pass\n'
-        pymod = self.pycore.get_string_module(code)
+        pymod = libutils.get_string_module(self.project, code)
         name_finder = rope.base.evaluate.ScopeNameFinder(pymod)
         with self.assertRaises(exceptions.RopeError):
             name_finder.get_pyname_at(code.index('pass'))
 
     def test_one_liners(self):
         code = 'var = 1\ndef f(): var = 2\nprint var\n'
-        pymod = self.pycore.get_string_module(code)
+        pymod = libutils.get_string_module(self.project, code)
         name_finder = rope.base.evaluate.ScopeNameFinder(pymod)
         pyname = name_finder.get_pyname_at(code.rindex('var'))
         self.assertEquals(pymod['var'], pyname)
 
     def test_one_liners_with_line_breaks(self):
         code = 'var = 1\ndef f(\n): var = 2\nprint var\n'
-        pymod = self.pycore.get_string_module(code)
+        pymod = libutils.get_string_module(self.project, code)
         name_finder = rope.base.evaluate.ScopeNameFinder(pymod)
         pyname = name_finder.get_pyname_at(code.rindex('var'))
         self.assertEquals(pymod['var'], pyname)
 
     def test_one_liners_with_line_breaks2(self):
         code = 'var = 1\ndef f(\np): var = 2\nprint var\n'
-        pymod = self.pycore.get_string_module(code)
+        pymod = libutils.get_string_module(self.project, code)
         name_finder = rope.base.evaluate.ScopeNameFinder(pymod)
         pyname = name_finder.get_pyname_at(code.rindex('var'))
         self.assertEquals(pymod['var'], pyname)
