@@ -1,4 +1,6 @@
+import os
 import os.path
+import shutil
 try:
     import unittest2 as unittest
 except ImportError:
@@ -78,11 +80,12 @@ class ProjectTest(unittest.TestCase):
 
     def test_failure_when_project_root_exists_and_is_a_file(self):
         project_root = 'sampleproject2'
-        open(project_root, 'w').close()
-        with self.assertRaises(RopeError):
-            Project(project_root)
-
-        testutils.remove_recursively(project_root)
+        try:
+            open(project_root, 'w').close()
+            with self.assertRaises(RopeError):
+                Project(project_root)
+        finally:
+            testutils.remove_recursively(project_root)
 
     def test_creating_folders(self):
         folderName = 'SampleFolder'
@@ -222,6 +225,19 @@ class ProjectTest(unittest.TestCase):
         self.assertTrue(folderPath == children[0].path or
                         folderPath == children[1].path)
 
+    def test_does_not_fail_for_permission_denied(self):
+        bad_dir = os.path.join(self.sample_folder, "bad_dir")
+        os.makedirs(bad_dir)
+        self.addCleanup(shutil.rmtree, bad_dir)
+        os.chmod(bad_dir, 0o000)
+        try:
+            parent = self.project.get_resource(self.sample_folder)
+
+            parent.get_children()
+
+        finally:
+            os.chmod(bad_dir, 0o755)
+
     def test_getting_files(self):
         files = self.project.root.get_files()
         self.assertEquals(1, len(files))
@@ -284,7 +300,7 @@ class ProjectTest(unittest.TestCase):
         src_folder = os.path.join(root, 'src')
         os.mkdir(src_folder)
         test_pyc = os.path.join(src_folder, 'test.pyc')
-        file(test_pyc, 'w').close()
+        open(test_pyc, 'w').close()
         for x in self.project.get_files():
             self.assertNotEquals('src/test.pyc', x.path)
 
@@ -469,7 +485,7 @@ class ProjectTest(unittest.TestCase):
         self.assertEquals(myfolder, path_to_resource(
                           self.project, myfolder.real_path, type='folder'))
 
-    @testutils.run_only_for_unix
+    @testutils.skipNotPOSIX()
     def test_ignoring_symlinks_inside_project(self):
         project2 = testutils.sample_project(folder_name='sampleproject2')
         mod = project2.root.create_file('mod.py')
@@ -481,6 +497,58 @@ class ProjectTest(unittest.TestCase):
         finally:
             testutils.remove_project(project2)
 
+    def test_getting_empty_source_folders(self):
+        self.assertEquals([], self.project.get_source_folders())
+
+    def test_root_source_folder(self):
+        self.project.root.create_file('sample.py')
+        source_folders = self.project.get_source_folders()
+        self.assertEquals(1, len(source_folders))
+        self.assertTrue(self.project.root in source_folders)
+
+    def test_root_source_folder2(self):
+        self.project.root.create_file('mod1.py')
+        self.project.root.create_file('mod2.py')
+        source_folders = self.project.get_source_folders()
+        self.assertEquals(1, len(source_folders))
+        self.assertTrue(self.project.root in source_folders)
+
+    def test_src_source_folder(self):
+        src = self.project.root.create_folder('src')
+        src.create_file('sample.py')
+        source_folders = self.project.get_source_folders()
+        self.assertEquals(1, len(source_folders))
+        self.assertTrue(self.project.get_resource('src') in source_folders)
+
+    def test_packages(self):
+        src = self.project.root.create_folder('src')
+        pkg = src.create_folder('package')
+        pkg.create_file('__init__.py')
+        source_folders = self.project.get_source_folders()
+        self.assertEquals(1, len(source_folders))
+        self.assertTrue(src in source_folders)
+
+    def test_multi_source_folders(self):
+        src = self.project.root.create_folder('src')
+        package = src.create_folder('package')
+        package.create_file('__init__.py')
+        test = self.project.root.create_folder('test')
+        test.create_file('alltests.py')
+        source_folders = self.project.get_source_folders()
+        self.assertEquals(2, len(source_folders))
+        self.assertTrue(src in source_folders)
+        self.assertTrue(test in source_folders)
+
+    def test_multi_source_folders2(self):
+        testutils.create_module(self.project, 'mod1')
+        src = self.project.root.create_folder('src')
+        package = testutils.create_package(self.project, 'package', src)
+        testutils.create_module(self.project, 'mod2', package)
+        source_folders = self.project.get_source_folders()
+        self.assertEquals(2, len(source_folders))
+        self.assertTrue(self.project.root in source_folders and
+                        src in source_folders)
+
 
 class ResourceObserverTest(unittest.TestCase):
 
@@ -658,7 +726,7 @@ class ResourceObserverTest(unittest.TestCase):
         sample_observer = _SampleObserver()
         self.project.add_observer(FilteredResourceObserver(sample_observer,
                                                            [my_file]))
-        file(my_file.real_path, 'w').close()
+        open(my_file.real_path, 'w').close()
         self.project.validate(root)
         self.assertEquals(my_file, sample_observer.last_created)
         self.assertEquals(1, sample_observer.change_count)
@@ -669,7 +737,7 @@ class ResourceObserverTest(unittest.TestCase):
         sample_observer = _SampleObserver()
         self.project.add_observer(FilteredResourceObserver(sample_observer,
                                                            [my_file]))
-        file(my_file.real_path, 'w').close()
+        open(my_file.real_path, 'w').close()
         self.project.validate(root)
         self.project.validate(root)
         self.assertEquals(my_file, sample_observer.last_created)
@@ -762,7 +830,7 @@ class OutOfProjectTest(unittest.TestCase):
 
     def test_simple_out_of_project_file(self):
         sample_file_path = os.path.join(self.test_directory, 'sample.txt')
-        sample_file = file(sample_file_path, 'w')
+        sample_file = open(sample_file_path, 'w')
         sample_file.write('sample content\n')
         sample_file.close()
         sample_resource = self.no_project.get_resource(sample_file_path)
@@ -775,13 +843,13 @@ class OutOfProjectTest(unittest.TestCase):
         self.assertEquals([], sample_folder.get_children())
 
         sample_file_path = os.path.join(sample_folder_path, 'sample.txt')
-        file(sample_file_path, 'w').close()
+        open(sample_file_path, 'w').close()
         sample_resource = self.no_project.get_resource(sample_file_path)
         self.assertEquals(sample_resource, sample_folder.get_children()[0])
 
     def test_using_absolute_path(self):
         sample_file_path = os.path.join(self.test_directory, 'sample.txt')
-        file(sample_file_path, 'w').close()
+        open(sample_file_path, 'w').close()
         normal_sample_resource = self.no_project.get_resource(sample_file_path)
         absolute_sample_resource = \
             self.no_project.get_resource(os.path.abspath(sample_file_path))
@@ -794,7 +862,7 @@ class OutOfProjectTest(unittest.TestCase):
         self.assertEquals([], sample_folder.get_children())
 
         sample_file_path = os.path.join(sample_folder_path, 'sample.txt')
-        file(sample_file_path, 'w').close()
+        open(sample_file_path, 'w').close()
         sample_resource = self.no_project.get_resource(sample_file_path)
         self.assertTrue(sample_folder.has_child('sample.txt'))
         self.assertFalse(sample_folder.has_child('doesnothave.txt'))
@@ -803,7 +871,7 @@ class OutOfProjectTest(unittest.TestCase):
 
     def test_out_of_project_files_and_path_to_resource(self):
         sample_file_path = os.path.join(self.test_directory, 'sample.txt')
-        sample_file = file(sample_file_path, 'w')
+        sample_file = open(sample_file_path, 'w')
         sample_file.write('sample content\n')
         sample_file.close()
         sample_resource = self.no_project.get_resource(sample_file_path)
@@ -937,10 +1005,9 @@ class RopeFolderTest(unittest.TestCase):
     def test_ignoring_syntax_errors(self):
         self.project = testutils.sample_project(ropefolder=None,
                                                 ignore_syntax_errors=True)
-        pycore = self.project.pycore
         mod = testutils.create_module(self.project, 'mod')
         mod.write('xyz print')
-        pymod = pycore.resource_to_pyobject(mod)  # noqa
+        pymod = self.project.get_pymodule(mod)  # noqa
 
     def test_compressed_history(self):
         self.project = testutils.sample_project(compress_history=True)
