@@ -4,6 +4,11 @@ from rope.base import ast
 from rope.refactor import patchedast
 from ropetest import testutils
 
+try:
+    basestring
+except NameError:
+    basestring = (str, bytes)
+
 
 class PatchedASTTest(unittest.TestCase):
 
@@ -432,7 +437,7 @@ class PatchedASTTest(unittest.TestCase):
             'ImportFrom', ['from', ' ', 'x', ' ', 'import', ' ', 'alias'])
         checker.check_children('alias', ['y'])
 
-    @testutils.run_only_for_25
+    @testutils.only_for('2.5')
     def test_from_node(self):
         source = 'from ..x import y as z\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -443,7 +448,7 @@ class PatchedASTTest(unittest.TestCase):
                            'import', ' ', 'alias'])
         checker.check_children('alias', ['y', ' ', 'as', ' ', 'z'])
 
-    @testutils.run_only_for_25
+    @testutils.only_for('2.5')
     def test_from_node_relative_import(self):
         source = 'from . import y as z\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -573,6 +578,43 @@ class PatchedASTTest(unittest.TestCase):
             'comprehension', ['for', ' ', 'Name', ' ', 'in', ' ',
                               'Call', ' ', 'if', ' ', 'Name'])
 
+    def test_set_comp_node(self):
+        # make sure we are in a python version with set comprehensions
+        source = '{i for i in range(1) if True}\n'
+
+        try:
+            eval(source)
+        except SyntaxError:
+            return
+
+        ast_frag = patchedast.get_patched_ast(source, True)
+        checker = _ResultChecker(self, ast_frag)
+        checker.check_region('SetComp', 0, len(source) - 1)
+        checker.check_children(
+            'SetComp', ['{', '', 'Name', ' ', 'comprehension', '', '}'])
+        checker.check_children(
+            'comprehension', ['for', ' ', 'Name', ' ', 'in', ' ',
+                              'Call', ' ', 'if', ' ', 'Name'])
+
+    def test_dict_comp_node(self):
+        # make sure we are in a python version with dict comprehensions
+        source = '{i:i for i in range(1) if True}\n'
+
+        try:
+            eval(source)
+        except SyntaxError:
+            return
+
+        ast_frag = patchedast.get_patched_ast(source, True)
+        checker = _ResultChecker(self, ast_frag)
+        checker.check_region('DictComp', 0, len(source) - 1)
+        checker.check_children(
+            'DictComp', ['{', '', 'Name', '', ':', '', 'Name',
+                         ' ', 'comprehension', '', '}'])
+        checker.check_children(
+            'comprehension', ['for', ' ', 'Name', ' ', 'in', ' ',
+                              'Call', ' ', 'if', ' ', 'Name'])
+
     def test_ext_slice_node(self):
         source = 'x = xs[0,:]\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -702,7 +744,7 @@ class PatchedASTTest(unittest.TestCase):
             'While', ['while', ' ', 'Name', '', ':', '\n    ', 'Pass', '\n',
                       'else', '', ':', '\n    ', 'Pass'])
 
-    @testutils.run_only_for_25
+    @testutils.only_for('2.5')
     def test_with_node(self):
         source = 'from __future__ import with_statement\nwith a as ' \
             'b:\n    pass\n'
@@ -744,7 +786,7 @@ class PatchedASTTest(unittest.TestCase):
             ['except', ' ', 'Name', ' ', 'as', ' ', 'Name', '', ':',
              '\n    ', 'Pass'])
 
-    @testutils.run_only_for_25
+    @testutils.only_for('2.5')
     def test_try_except_and_finally_node(self):
         source = 'try:\n    pass\nexcept:\n    pass\nfinally:\n    pass\n'
         ast_frag = patchedast.get_patched_ast(source, True)
@@ -785,7 +827,7 @@ class PatchedASTTest(unittest.TestCase):
         source = '1;\n'
         patchedast.get_patched_ast(source, True)
 
-    @testutils.run_only_for_25
+    @testutils.only_for('2.5')
     def test_if_exp_node(self):
         source = '1 if True else 2\n'
         ast_frag = patchedast.get_patched_ast(source, True)
